import pandas as pd
import glob
from fpdf import FPDF
from pathlib import Path
import os


def generate(invoices_path, pdfs_paths, image_path, product_id, product_name, amount_purchased,
             price_per_unit,total_price):
    """
        This funciorn converts invoice excel files into PDF
        :param invoices_path:
        :param pdf_paths:
        :param  image_path:
        :param product_id:
        :param product_name:
        :param amount_purchased:
        :param  price_per_unit:
        :param total_price:
        )

    """
    filepaths = glob.glob(f"{invoices_path}/*.xlsx")

    for filepath in filepaths:
        pdf = FPDF(orientation='P', unit='mm', format='A4')
        pdf.add_page()

        filename = Path(filepath).stem
        invoice_nr, invoice_dt = filename.split('-')

        pdf.set_font(family='Arial',size=16, style='B')
        pdf.cell(w=50, h=8, txt=f"Invoice # {invoice_nr}", ln=1) # ln adds a break line

        pdf.set_font(family='Arial',size=16, style='B')
        pdf.cell(w=50, h=8, txt=f"Date # {invoice_dt}",ln=1)

        df = pd.read_excel(filepath, sheet_name='Sheet 1')
        # Add headers
        headers = df.columns
        headers = [header.replace('_'," ").title() for header in headers]
        pdf.set_font(family='Arial', size=10, style='B')
        pdf.set_text_color(80, 80, 80)
        pdf.cell(w=30, h=8, txt=headers[0], border=1)
        pdf.cell(w=60, h=8, txt=headers[1], border=1)
        pdf.cell(w=45, h=8, txt=headers[2], border=1)
        pdf.cell(w=30, h=8, txt=headers[3], border=1)
        pdf.cell(w=30, h=8, txt=headers[4], border=1, ln=1)
        # Add rows
        for index, row in df.iterrows():
            pdf.set_font(family='Arial', size=10)
            pdf.set_text_color(80,80,80)
            pdf.cell(w=30, h=8, txt=str(row[product_id]), border=1)
            pdf.cell(w=60, h=8, txt=str(row[product_name]), border=1)
            pdf.cell(w=45, h=8, txt=str(row[amount_purchased]), border=1)
            pdf.cell(w=30, h=8, txt=str(row[price_per_unit]), border=1)
            pdf.cell(w=30, h=8, txt=str(row[total_price]), border=1, ln=1)

        # Total Price
        total_sum = str(df[total_price].sum())
        pdf.set_font(family='Arial', size=10, style='B')
        pdf.set_text_color(80, 80, 80)
        pdf.cell(w=30, h=8, txt="")
        pdf.cell(w=60, h=8, txt="")
        pdf.cell(w=45, h=8, txt="")
        pdf.cell(w=30, h=8, txt="")
        pdf.cell(w=30, h=8, txt=total_sum, border=1, ln=1)
        # Add sentence and logo
        pdf.set_text_color(0, 0, 0)
        pdf.set_font(family='Arial', size=14, style='B')
        pdf.cell(w=30, h=8, txt=f"The Total Price is {total_sum}", ln=1)
        pdf.cell(w=30, h=8, txt=f"PythonHow")
        pdf.image(image_path, w=10)

        if not os.path.exists(pdfs_paths):
            os.makedirs(pdfs_paths)
        pdf.output(f"{pdfs_paths}/{filename}.pdf")
